/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IFluidHandleContext, IRequest, IResponse } from "@fluidframework/core-interfaces";
import { FluidObjectHandle } from "@fluidframework/datastore";
import { ISharedObject } from "./types";
/**
 * Handle for shared object
 * This object is used for already loaded (in-memory) shared object
 * and is used only for serialization purposes.
 * De-serialization process goes through FluidObjectHandle and request flow:
 * FluidDataStoreRuntime.request() recognizes requests in the form of '/<shared object id>'
 * and loads shared object.
 */
export declare class SharedObjectHandle extends FluidObjectHandle<ISharedObject> {
    /**
     * Whether services have been attached for the associated shared object.
     */
    get isAttached(): boolean;
    /**
     * Creates a new SharedObjectHandle.
     * @param value - The shared object this handle is for.
     * @param path - The id of the shared object. It is also the path to this object relative to the routeContext.
     * @param routeContext - The parent IFluidHandleContext that has a route to this handle.
     */
    constructor(value: ISharedObject, path: string, routeContext: IFluidHandleContext);
    /**
     * Attaches all bound handles first (which may in turn attach further handles), then attaches this handle.
     * When attaching the handle, it registers the associated shared object.
     */
    attachGraph(): void;
    /**
     * Returns 404.
     * @param request - The request to make
     * @returns A 404 error
     */
    request(request: IRequest): Promise<IResponse>;
}
//# sourceMappingURL=handle.d.ts.map